[**Расширенные параметры**](./introduction.md) > **Документация служб перевода** _(текущая)_

---

### Просмотр доступных служб перевода через Командную строку

Вы можете подтвердить доступные службы перевода и их использование, распечатав справочное сообщение в командной строке.

```bash
pdf2zh_next -h
```

В конце сообщения справки вы можете просмотреть подробную информацию о различных службах перевода.

<div align="right"> 
<h6><small>Часть содержимого этой страницы была переведена GPT и может содержать ошибки.</small></h6>